@@ -1,9 +1,7 @@
-import logging
 from typing import TYPE_CHECKING
 
 import naff.api.events as events
 
-from naff.client.const import logger_name
 from ._template import EventMixinTemplate, Processor
 from naff.models import StageInstance
 
@@ -12,8 +10,6 @@ if TYPE_CHECKING:
 
 __all__ = ("StageEvents",)
 
-log = logging.getLogger(logger_name)
-
 
 class StageEvents(EventMixinTemplate):
     @Processor.define()
