@@ -1,7 +1,8 @@
-from typing import TYPE_CHECKING, Any, Dict, List
+from typing import TYPE_CHECKING, cast
 
 import discord_typings
 
+from naff.models.naff.protocols import CanRequest
 from naff.client.const import GLOBAL_SCOPE
 from ..route import Route
 
@@ -13,9 +14,7 @@ if TYPE_CHECKING:
     from naff import UPLOADABLE_TYPE
 
 
-class InteractionRequests:
-    request: Any
-
+class InteractionRequests(CanRequest):
     async def delete_application_command(
         self, application_id: "Snowflake_Type", guild_id: "Snowflake_Type", command_id: "Snowflake_Type"
     ) -> None:
@@ -25,18 +24,21 @@ class InteractionRequests:
         Args:
             application_id: the what application to delete for
             guild_id: specify a guild to delete commands from
-            command_id The command to delete
+            command_id: the command to delete
 
         """
         if guild_id == GLOBAL_SCOPE:
-            return await self.request(Route("DELETE", f"/applications/{application_id}/commands/{command_id}"))
-        return await self.request(
-            Route("DELETE", f"/applications/{application_id}/guilds/{guild_id}/commands/{command_id}")
-        )
+            await self.request(Route("DELETE", f"/applications/{int(application_id)}/commands/{int(command_id)}"))
+        else:
+            await self.request(
+                Route(
+                    "DELETE", f"/applications/{int(application_id)}/guilds/{int(guild_id)}/commands/{int(command_id)}"
+                )
+            )
 
     async def get_application_commands(
         self, application_id: "Snowflake_Type", guild_id: "Snowflake_Type", with_localisations: bool = True
-    ) -> List[discord_typings.ApplicationCommandData]:
+    ) -> list[discord_typings.ApplicationCommandData]:
         """
         Get all application commands for this application from discord.
 
@@ -60,8 +62,8 @@ class InteractionRequests:
         )
 
     async def overwrite_application_commands(
-        self, app_id: "Snowflake_Type", data: List[Dict], guild_id: "Snowflake_Type" = None
-    ) -> List[discord_typings.ApplicationCommandData]:
+        self, app_id: "Snowflake_Type", data: list[dict], guild_id: "Snowflake_Type"  # todo type "data"
+    ) -> list[discord_typings.ApplicationCommandData]:
         """
         Take a list of commands and overwrite the existing command list within the given scope
 
@@ -72,11 +74,15 @@ class InteractionRequests:
 
         """
         if guild_id == GLOBAL_SCOPE:
-            return await self.request(Route("PUT", f"/applications/{app_id}/commands"), payload=data)
-        return await self.request(Route("PUT", f"/applications/{app_id}/guilds/{guild_id}/commands"), payload=data)
+            result = await self.request(Route("PUT", f"/applications/{app_id}/commands"), payload=data)
+        else:
+            result = await self.request(
+                Route("PUT", f"/applications/{app_id}/guilds/{int(guild_id)}/commands"), payload=data
+            )
+        return cast(list[discord_typings.ApplicationCommandData], result)
 
     async def create_application_command(
-        self, app_id: "Snowflake_Type", command: Dict, guild_id: "Snowflake_Type"
+        self, app_id: "Snowflake_Type", command: dict, guild_id: "Snowflake_Type"
     ) -> discord_typings.ApplicationCommandData:
         """
         Add a given command to scope.
@@ -90,8 +96,12 @@ class InteractionRequests:
             An application command object
         """
         if guild_id == GLOBAL_SCOPE:
-            return await self.request(Route("POST", f"/applications/{app_id}/commands"), payload=command)
-        return await self.request(Route("POST", f"/applications/{app_id}/guilds/{guild_id}/commands"), payload=command)
+            result = await self.request(Route("POST", f"/applications/{app_id}/commands"), payload=command)
+        else:
+            result = await self.request(
+                Route("POST", f"/applications/{app_id}/guilds/{int(guild_id)}/commands"), payload=command
+            )
+        return cast(discord_typings.ApplicationCommandData, result)
 
     async def post_initial_response(
         self, payload: dict, interaction_id: str, token: str, files: list["UPLOADABLE_TYPE"] | None = None
@@ -123,7 +133,9 @@ class InteractionRequests:
             files: The files to send with this interaction
 
         """
-        return await self.request(Route("POST", f"/webhooks/{application_id}/{token}"), payload=payload, files=files)
+        return await self.request(
+            Route("POST", f"/webhooks/{int(application_id)}/{token}"), payload=payload, files=files
+        )
 
     async def edit_interaction_message(
         self,
@@ -147,12 +159,15 @@ class InteractionRequests:
             The edited message data.
 
         """
-        return await self.request(
-            Route("PATCH", f"/webhooks/{application_id}/{token}/messages/{message_id}"), payload=payload, files=files
+        result = await self.request(
+            Route("PATCH", f"/webhooks/{int(application_id)}/{token}/messages/{message_id}"),
+            payload=payload,
+            files=files,
         )
+        return cast(discord_typings.MessageData, result)
 
     async def get_interaction_message(
-        self, application_id: str, token: str, message_id: str = "@original"
+        self, application_id: "Snowflake_Type", token: str, message_id: str = "@original"
     ) -> discord_typings.MessageData:
         """
         Gets an existing interaction message.
@@ -166,14 +181,15 @@ class InteractionRequests:
             The message data.
 
         """
-        return await self.request(Route("GET", f"/webhooks/{application_id}/{token}/messages/{message_id}"))
+        result = await self.request(Route("GET", f"/webhooks/{int(application_id)}/{token}/messages/{message_id}"))
+        return cast(discord_typings.MessageData, result)
 
     async def edit_application_command_permissions(
         self,
         application_id: "Snowflake_Type",
         scope: "Snowflake_Type",
-        cmd_id: "Snowflake_Type",
-        permissions: List[dict],
+        command_id: "Snowflake_Type",
+        permissions: list[dict],  # todo better typing
     ) -> discord_typings.ApplicationCommandPermissionsData:
         """
         Edits command permissions for a specific command.
@@ -181,40 +197,46 @@ class InteractionRequests:
         Args:
             application_id: the id of the application
             scope: The scope this command is in
-            cmd_id: The command id to edit
+            command_id: The command id to edit
             permissions: The permissions to set to this command
 
         Returns:
             Guild Application Command Permissions
 
         """
-        return await self.request(
-            Route("PUT", f"/applications/{application_id}/guilds/{scope}/commands/{cmd_id}/permissions"),
+        result = await self.request(
+            Route(
+                "PUT", f"/applications/{int(application_id)}/guilds/{int(scope)}/commands/{int(command_id)}/permissions"
+            ),
             payload=permissions,
         )
+        return cast(discord_typings.ApplicationCommandPermissionsData, result)
 
     async def get_application_command_permissions(
-        self, application_id: "Snowflake_Type", scope: "Snowflake_Type", cmd_id: "Snowflake_Type"
-    ) -> List[discord_typings.ApplicationCommandPermissionsData]:
+        self, application_id: "Snowflake_Type", scope: "Snowflake_Type", command_id: "Snowflake_Type"
+    ) -> list[discord_typings.ApplicationCommandPermissionsData]:
         """
         Get permission data for a command.
 
         Args:
             application_id: the id of the application
             scope: The scope this command is in
-            cmd_id: The command id to edit
+            command_id: The command id to edit
 
         Returns:
             guild application command permissions
 
         """
-        return await self.request(
-            Route("GET", f"/applications/{application_id}/guilds/{scope}/commands/{cmd_id}/permissions")
+        result = await self.request(
+            Route(
+                "GET", f"/applications/{int(application_id)}/guilds/{int(scope)}/commands/{int(command_id)}/permissions"
+            )
         )
+        return cast(list[discord_typings.ApplicationCommandPermissionsData], result)
 
     async def batch_get_application_command_permissions(
         self, application_id: "Snowflake_Type", scope: "Snowflake_Type"
-    ) -> List[discord_typings.ApplicationCommandPermissionsData]:
+    ) -> list[discord_typings.ApplicationCommandPermissionsData]:
         """
         Get permission data for all commands in a scope.
 
@@ -226,4 +248,7 @@ class InteractionRequests:
             list of guild application command permissions
 
         """
-        return await self.request(Route("GET", f"/applications/{application_id}/guilds/{scope}/commands/permissions"))
+        result = await self.request(
+            Route("GET", f"/applications/{int(application_id)}/guilds/{int(scope)}/commands/permissions")
+        )
+        return cast(list[discord_typings.ApplicationCommandPermissionsData], result)
