@@ -1,15 +1,18 @@
-from typing import Awaitable, Callable, Union
+from typing import Awaitable, Callable
 
-from naff.models.discord.role import Role
 from naff.models.discord.snowflake import Snowflake_Type, to_snowflake
 from naff.models.naff.context import Context
 
+from naff.models.discord.role import Role
+from naff.models.discord.user import Member
+
+
 __all__ = ("has_role", "has_any_role", "has_id", "is_owner", "guild_only", "dm_only")
 
 TYPE_CHECK_FUNCTION = Callable[[Context], Awaitable[bool]]
 
 
-def has_role(role: Union[Snowflake_Type, Role]) -> TYPE_CHECK_FUNCTION:
+def has_role(role: Snowflake_Type | Role) -> TYPE_CHECK_FUNCTION:
     """
     Check if the user has the given role.
 
@@ -21,12 +24,13 @@ def has_role(role: Union[Snowflake_Type, Role]) -> TYPE_CHECK_FUNCTION:
     async def check(ctx: Context) -> bool:
         if ctx.guild is None:
             return False
-        return ctx.author.has_role(role)
+        author: Member = ctx.author  # pyright: ignore [reportGeneralTypeIssues]
+        return author.has_role(role)
 
     return check
 
 
-def has_any_role(*roles: Union[Snowflake_Type, Role]) -> TYPE_CHECK_FUNCTION:
+def has_any_role(*roles: Snowflake_Type | Role) -> TYPE_CHECK_FUNCTION:
     """
     Checks if the user has any of the given roles.
 
@@ -38,7 +42,8 @@ def has_any_role(*roles: Union[Snowflake_Type, Role]) -> TYPE_CHECK_FUNCTION:
         if ctx.guild is None:
             return False
 
-        if any(ctx.author.has_role(to_snowflake(r)) for r in roles):
+        author: Member = ctx.author  # pyright: ignore [reportGeneralTypeIssues]
+        if any(author.has_role(to_snowflake(r)) for r in roles):
             return True
         return False
 
@@ -50,7 +55,7 @@ def has_id(user_id: int) -> TYPE_CHECK_FUNCTION:
     Checks if the author has the desired ID.
 
     Args:
-        coro: the function to check
+        user_id: id of the user to check for
 
     """
 
@@ -61,13 +66,7 @@ def has_id(user_id: int) -> TYPE_CHECK_FUNCTION:
 
 
 def is_owner() -> TYPE_CHECK_FUNCTION:
-    """
-    Checks if the author is the owner of the bot. This respects the `client.owner_ids` list.
-
-    Args:
-        coro: the function to check
-
-    """
+    """Checks if the author is the owner of the bot. This respects the `client.owner_ids` list."""
 
     async def check(ctx: Context) -> bool:
         _owner_ids: set = ctx.bot.owner_ids.copy()
